from typing import List


def generate_latex_table(values: List[List[str]], file_to_save: str):
    with open(file_to_save, "a") as file:
        file.write("\\begin{center}\n")
        file.write("\\begin{tabular}{" + "c" * len(values[0]) + "}\n")
        for row in values:
            file.write(" & ".join(row) + "\\\\\n")
        file.write("\\end{tabular}\n")
        file.write("\\end{center}\n")



def generate_latex_image(image_path, output_path, image_width='\\textwidth'):
    latex_content = r'''
\begin{figure}[ht]
    \centering
    \includegraphics[width=''' + image_width + ']{' + image_path + r'''}
    \caption{Example Image}
\end{figure}
    '''

    with open(output_path, 'a') as tex_file:
        tex_file.write(latex_content)



from setuptools import setup, find_packages

import json
import os

def read_pipenv_dependencies(fname):
    """Получаем из Pipfile.lock зависимости по умолчанию."""
    filepath = os.path.join(os.path.dirname(__file__), fname)
    with open(filepath) as lockfile:
        lockjson = json.load(lockfile)
        return [dependency for dependency in lockjson.get('default')]

if __name__ == '__main__':
    setup(
        name='latex_functions',
        version=os.getenv('PACKAGE_VERSION', '0.0.1'),
        package_dir={'': 'src'},
        packages=find_packages('src', include=[
            'latex_functions*'
        ]),
        description='A package for some latex functions.',
        install_requires=[
              *read_pipenv_dependencies('Pipfile.lock'),
        ]
    )